pyglet.resource
===============

.. automodule:: pyglet.resource
  :members:
  :noindex:
  :undoc-members:


Functions
---------

.. autofunction:: reindex
.. autofunction:: file
.. autofunction:: location
.. autofunction:: add_font
.. autofunction:: image
.. autofunction:: animation
.. autofunction:: texture
.. autofunction:: media
.. autofunction:: model
.. autofunction:: shader
.. autofunction:: html
.. autofunction:: attributed
.. autofunction:: text
.. autofunction:: get_cached_image_names
.. autofunction:: get_cached_animation_names
.. autofunction:: get_texture_bins
.. autofunction:: get_cached_texture_names


Exceptions
----------

.. autoclass:: ResourceNotFoundException
  :members:
  :undoc-members:

.. autoclass:: UndetectableShaderType
  :members:
  :undoc-members:
